<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\MainBundle\Controller;

use Chill\MainBundle\Notification\NotificationRenderer;
use Chill\MainBundle\Pagination\PaginatorFactory;
use Chill\MainBundle\Repository\NotificationRepository;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Security;

/**
 * @Route("/{_locale}/notification")
 */
class NotificationController extends AbstractController
{
    private $security;

    public function __construct(Security $security)
    {
        $this->security = $security;
    }

    /**
     * @Route("/show", name="chill_main_notification_show")
     */
    public function showAction(
        NotificationRepository $notificationRepository,
        NotificationRenderer $notificationRenderer,
        PaginatorFactory $paginatorFactory
    ) {
        $currentUser = $this->security->getUser();

        $notificationsNbr = $notificationRepository->countAllForAttendee(($currentUser));
        $paginator = $paginatorFactory->create($notificationsNbr);

        $notifications = $notificationRepository->findAllForAttendee(
            $currentUser,
            $limit = $paginator->getItemsPerPage(),
            $offset = $paginator->getCurrentPage()->getFirstItemNumber()
        );

        $templateData = [];

        foreach ($notifications as $notification) {
            $data = [
                'template' => $notificationRenderer->getTemplate($notification),
                'template_data' => $notificationRenderer->getTemplateData($notification),
                'notification' => $notification,
            ];
            $templateData[] = $data;
        }

        return $this->render('@ChillMain/Notification/show.html.twig', [
            'datas' => $templateData,
            'notifications' => $notifications,
            'paginator' => $paginator,
        ]);
    }
}
