<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\MainBundle\Notification;

use Chill\ActivityBundle\Notification\ActivityNotificationRenderer;
use Chill\MainBundle\Entity\Notification;
use Chill\PersonBundle\Notification\AccompanyingPeriodNotificationRenderer;
use Exception;

final class NotificationRenderer
{
    private array $renderers;

    public function __construct(
        AccompanyingPeriodNotificationRenderer $accompanyingPeriodNotificationRenderer,
        ActivityNotificationRenderer $activityNotificationRenderer
    ) {
        // TODO configure automatically
        // TODO CREER UNE INTERFACE POUR ETRE SUR QUE LES RENDERERS SONT OK

        $this->renderers[] = $accompanyingPeriodNotificationRenderer;
        $this->renderers[] = $activityNotificationRenderer;
    }

    public function getTemplate(Notification $notification)
    {
        return $this->getRenderer($notification)->getTemplate();
    }

    public function getTemplateData(Notification $notification)
    {
        return $this->getRenderer($notification)->getTemplateData($notification);
    }

    private function getRenderer(Notification $notification)
    {
        foreach ($this->renderers as $renderer) {
            if ($renderer->supports($notification)) {
                return $renderer;
            }
        }

        throw new Exception('No renderer for ' . $notification);
    }
}
