<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\MainBundle\Repository;

use Chill\MainBundle\Entity\Notification;
use Chill\MainBundle\Entity\User;
use Doctrine\ORM\EntityManagerInterface;
use Doctrine\ORM\EntityRepository;
use Doctrine\ORM\Query;
use Doctrine\Persistence\ObjectRepository;

final class NotificationRepository implements ObjectRepository
{
    private EntityRepository $repository;

    public function __construct(EntityManagerInterface $entityManager)
    {
        $this->repository = $entityManager->getRepository(Notification::class);
    }

    public function countAllForAttendee(User $addressee): int // TODO passer à attendees avec S
    {
        $query = $this->queryAllForAttendee($addressee, $countQuery = true);

        return $query->getSingleScalarResult();
    }

    public function find($id, $lockMode = null, $lockVersion = null): ?Notification
    {
        return $this->repository->find($id, $lockMode, $lockVersion);
    }

    /**
     * @return Notification[]
     */
    public function findAll(): array
    {
        return $this->repository->findAll();
    }

    /**
     * @param mixed|null $limit
     * @param mixed|null $offset
     *
     * @return Notification[]
     */
    public function findAllForAttendee(User $addressee, $limit = null, $offset = null): array // TODO passer à attendees avec S
    {
        $query = $this->queryAllForAttendee($addressee);

        if ($limit) {
            $query = $query->setMaxResults($limit);
        }

        if ($offset) {
            $query = $query->setFirstResult($offset);
        }

        return $query->getResult();
    }

    /**
     * @param mixed|null $limit
     * @param mixed|null $offset
     *
     * @return Notification[]
     */
    public function findBy(array $criteria, ?array $orderBy = null, $limit = null, $offset = null): array
    {
        return $this->repository->findBy($criteria, $orderBy, $limit, $offset);
    }

    public function findOneBy(array $criteria, ?array $orderBy = null): ?Notification
    {
        return $this->repository->findOneBy($criteria, $orderBy);
    }

    public function getClassName()
    {
        return Notification::class;
    }

    private function queryAllForAttendee(User $addressee, bool $countQuery = false): Query
    {
        $qb = $this->repository->createQueryBuilder('n');

        $select = 'n';

        if ($countQuery) {
            $select = 'count(n)';
        }

        $qb
            ->select($select)
            ->join('n.addressees', 'a')
            ->where('a = :addressee')
            ->setParameter('addressee', $addressee);

        return $qb->getQuery();
    }
}
