<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\MainBundle\Routing\MenuBuilder;

use Chill\MainBundle\Entity\User;
use Chill\MainBundle\Routing\LocalMenuBuilderInterface;
use Symfony\Component\Security\Core\Security;

class UserMenuBuilder implements LocalMenuBuilderInterface
{
    private Security $security;

    public function __construct(Security $security)
    {
        $this->security = $security;
    }

    public function buildMenu($menuId, \Knp\Menu\MenuItem $menu, array $parameters)
    {
        $user = $this->security->getUser();

        if ($user instanceof User) {
            if (null !== $user->getCurrentLocation()) {
                $locationTextMenu = $user->getCurrentLocation()->getName();
            } else {
                $locationTextMenu = 'Set a location';
            }

            $menu
                ->addChild(
                    $locationTextMenu,
                    ['route' => 'chill_main_user_currentlocation_edit']
                )
                ->setExtras([
                    'order' => -9999999,
                    'icon' => 'map-marker',
                ]);
            $menu
                ->addChild(
                    'Change password',
                    ['route' => 'change_my_password']
                )
                ->setExtras([
                    'order' => 99999999998,
                ]);
        }

        $menu
            ->addChild(
                'Logout',
                [
                    'route' => 'logout',
                ]
            )
            ->setExtras([
                'order' => 99999999999,
                'icon' => 'power-off',
            ]);
    }

    public static function getMenuIds(): array
    {
        return ['user'];
    }
}
