<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\MainBundle\Tests\Templating\Entity;

use Chill\MainBundle\Entity\Address;
use Chill\MainBundle\Entity\Country;
use Chill\MainBundle\Entity\PostalCode;
use Chill\MainBundle\Templating\Entity\AddressRender;
use Iterator;
use Symfony\Bundle\FrameworkBundle\Test\KernelTestCase;
use Symfony\Component\Templating\EngineInterface;

/**
 * @internal
 * @coversNothing
 */
final class AddressRenderTest extends KernelTestCase
{
    protected function setUp()
    {
        self::bootKernel();
    }

    public function addressDataProvider(): Iterator
    {
        $addr = new Address();
        $country = (new Country())
            ->setName(['fr' => 'Pays'])
            ->setCountryCode('BE');
        $postCode = new PostalCode();
        $postCode->setName('Locality')
            ->setCode('012345')
            ->setCountry($country);

        $addr->setStreet('Rue ABC')
            ->setStreetNumber('5')
            ->setPostcode($postCode);

        yield [$addr, 'Rue ABC, 5 - 012345 Locality'];
    }

    /**
     * @dataProvider addressDataProvider
     */
    public function testRenderString(Address $addr, string $expectedString): void
    {
        $engine = self::$container->get(EngineInterface::class);
        $renderer = new AddressRender($engine);

        $this->assertEquals($expectedString, $renderer->renderString($addr, []));

        return;
        $this->assertIsString($renderer->renderBox($addr, []));
    }
}
