<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\Controller;

use Chill\DocGeneratorBundle\Entity\DocGeneratorTemplate;
use Chill\DocGeneratorBundle\Repository\DocGeneratorTemplateRepository;
use Chill\MainBundle\Pagination\PaginatorFactory;
use Chill\MainBundle\Serializer\Model\Collection;
use Chill\PersonBundle\Entity\AccompanyingPeriod\AccompanyingPeriodWorkEvaluation;
use Chill\PersonBundle\Entity\SocialWork\Evaluation;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpKernel\Exception\BadRequestHttpException;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Serializer\Normalizer\AbstractNormalizer;
use Symfony\Component\Serializer\SerializerInterface;
use function count;
use function in_array;

class AccompanyingPeriodWorkEvaluationApiController
{
    private DocGeneratorTemplateRepository $docGeneratorTemplateRepository;

    private PaginatorFactory $paginatorFactory;

    private SerializerInterface $serializer;

    public function __construct(
        DocGeneratorTemplateRepository $docGeneratorTemplateRepository,
        SerializerInterface $serializer,
        PaginatorFactory $paginatorFactory
    ) {
        $this->docGeneratorTemplateRepository = $docGeneratorTemplateRepository;
        $this->serializer = $serializer;
        $this->paginatorFactory = $paginatorFactory;
    }

    /**
     * @Route("/api/1.0/person/docgen/template/by-evaluation/{id}.{_format}",
     * requirements={"format": "json"})
     */
    public function listTemplateByEvaluation(Evaluation $evaluation, string $_format): JsonResponse
    {
        if ('json' !== $_format) {
            throw new BadRequestHttpException('format not supported');
        }

        $evaluations =
            array_filter(
                $this->docGeneratorTemplateRepository
                    ->findByEntity(AccompanyingPeriodWorkEvaluation::class),
                static function (DocGeneratorTemplate $t) use ($evaluation) {
                    $ids = $t->getOptions()['evaluations'] ?? [];

                    return in_array($evaluation->getId(), $ids, true);
                }
            );

        $paginator = $this->paginatorFactory->create(count($evaluations));
        $paginator->setItemsPerPage(count($evaluations));

        return new JsonResponse($this->serializer->serialize(
            new Collection($evaluations, $paginator),
            'json',
            [
                AbstractNormalizer::GROUPS => ['read'],
            ]
        ), JsonResponse::HTTP_OK, [], true);
    }
}
