<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\Entity\SocialWork;

use DateInterval;
use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\Serializer\Annotation as Serializer;

/**
 * @ORM\Entity
 * @ORM\Table(name="chill_person_social_work_evaluation")
 * @Serializer\DiscriminatorMap(typeProperty="type", mapping={
 *     "social_work_evaluation": Evaluation::class
 * })
 */
class Evaluation
{
    /**
     * @ORM\Column(type="dateinterval", nullable=true, options={"default": null})
     * @Serializer\Groups({"read"})
     */
    private ?DateInterval $delay = null;

    /**
     * @ORM\Id
     * @ORM\GeneratedValue
     * @ORM\Column(type="integer")
     * @Serializer\Groups({"read", "docgen:read"})
     */
    private ?int $id = null;

    /**
     * @ORM\Column(type="dateinterval", nullable=true, options={"default": null})
     * @Serializer\Groups({"read"})
     */
    private ?DateInterval $notificationDelay = null;

    /**
     * @ORM\ManyToOne(
     *     targetEntity=SocialAction::class,
     *     inversedBy="evaluations"
     * )
     */
    private ?SocialAction $socialAction = null;

    /**
     * @ORM\Column(type="json")
     * @Serializer\Groups({"read", "docgen:read"})
     * @Serializer\Context({"is-translatable": true}, groups={"docgen:read"})
     */
    private array $title = [];

    public function getDelay(): ?DateInterval
    {
        return $this->delay;
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getNotificationDelay(): ?DateInterval
    {
        return $this->notificationDelay;
    }

    public function getSocialAction(): ?SocialAction
    {
        return $this->socialAction;
    }

    public function getTitle(): array
    {
        return $this->title;
    }

    public function setDelay(DateInterval $delay): self
    {
        $this->delay = $delay;

        return $this;
    }

    public function setNotificationDelay(DateInterval $notificationDelay): self
    {
        $this->notificationDelay = $notificationDelay;

        return $this;
    }

    public function setSocialAction(?SocialAction $socialAction): self
    {
        $this->socialAction = $socialAction;

        return $this;
    }

    public function setTitle(array $title): self
    {
        $this->title = $title;

        return $this;
    }
}
