<?php

/**
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\PersonBundle\Repository\AccompanyingPeriod;

use Chill\PersonBundle\Entity\AccompanyingPeriod;
use Chill\PersonBundle\Entity\AccompanyingPeriod\AccompanyingPeriodWork;
use Doctrine\ORM\EntityManagerInterface;
use Doctrine\ORM\EntityRepository;
use Doctrine\Persistence\ObjectRepository;

final class AccompanyingPeriodWorkRepository implements ObjectRepository
{
    private EntityRepository $repository;

    public function __construct(EntityManagerInterface $entityManager)
    {
        $this->repository = $entityManager->getRepository(AccompanyingPeriodWork::class);
    }

    public function countByAccompanyingPeriod(AccompanyingPeriod $period): int
    {
        return $this->repository->countByAccompanyingPeriod($period);
    }

    public function countBySocialActionWithDescendants(SocialAction $action): int
    {
        $qb = $this->buildQueryBySocialActionWithDescendants($action);
        $qb->select('COUNT(g)');

        return $qb
            ->getQuery()
            ->getSingleScalarResult();
    }

    public function find($id): ?AccompanyingPeriodWork
    {
        return $this->repository->find($id);
    }

    public function findAll(): array
    {
        return $this->repository->findAll();
    }

    public function findBy(array $criteria, ?array $orderBy = null, $limit = null, $offset = null): array
    {
        return $this->repository->findBy($criteria, $orderBy, $limit, $offset);
    }

    /**
     * @param mixed|null $orderBy
     * @param mixed|null $limit
     * @param mixed|null $offset
     *
     * @return AccompanyingPeriodWork[]
     */
    public function findByAccompanyingPeriod(AccompanyingPeriod $period, $orderBy = null, $limit = null, $offset = null): array
    {
        return $this->repository->findByAccompanyingPeriod($period, $orderBy, $limit, $offset);
    }

    public function findOneBy(array $criteria): ?AccompanyingPeriodWork
    {
        return $this->repository->findOneBy($criteria);
    }

    public function getClassName()
    {
        return AccompanyingPeriodWork::class;
    }

    public function toDelete()
    {
        $qb = $this->buildQueryBySocialActionWithDescendants($action);
        $qb->select('g');

        foreach ($orderBy as $sort => $order) {
            $qb->addOrderBy('g.' . $sort, $order);
        }

        return $qb
            ->setMaxResults($limit)
            ->setFirstResult($offset)
            ->getQuery()
            ->getResult();
    }

    private function buildQueryBySocialActionWithDescendants(SocialAction $action): QueryBuilder
    {
        $actions = $action->getDescendantsWithThis();

        $qb = $this->repository->createQueryBuilder('g');

        $orx = $qb->expr()->orX();
        $i = 0;

        foreach ($actions as $action) {
            $orx->add(":action_{$i} MEMBER OF g.socialActions");
            $qb->setParameter("action_{$i}", $action);
        }
        $qb->where($orx);

        return $qb;
    }
}
